<?php
// No direct access
defined('_JEXEC') or die('Restricted access');

/**
 * Controller two
 * 
 * Accepts an array of configuration values to the constructor. If no config 
 * passed, it will automatically determine the component and controller names.
 * Internally, sets the $database, $user, $view, and component $config.
 * 
 * Executable tasks are determined by method name. All public methods that end in 
 * "Task" (e.g., displayTask, editTask) are callable by the end user.
 * 
 * View name defaults to controller name with layout defaulting to task name. So,
 * a $controller of "One" and a $task of "two" will map to:
 *
 *    /{component name}
 *        /views
 *            /one
 *                /tmpl
 *                    /two.php
 */
class HelloControllerTwo extends \Hubzero\Component\SiteController
{
	/**
	 * Default task
	 * 
	 * @return     void
	 */
	public function displayTask() 
	{
		// Set the page title
		$this->_buildTitle();

		// Set the pathway
		$this->_buildPathway();

		// Retrieve the multiplier
		$this->view->multiplier = JRequest::getInt('multiplier', 5);

		// Error check
		if ($this->view->multiplier < 2) 
		{
			JError::raiseError(500, JText::_('COM_HELLO_MULTIPLIER_ERROR'));
			return;
		}

		// Set the query
		$this->database->setQuery('SELECT count(*) FROM `#__extensions`');

		// Execute the query and pass the result to the view
		$this->view->component_count = $this->database->loadResult();

		// Pass error messages to the view
		if ($this->getError()) 
		{
			foreach ($this->getErrors() as $error)
			{
				$this->view->setError($error);
			}
		}

		// Output the HTML
		$this->view->display();
	}

	/**
	 * Method to set the document path
	 * 
	 * @param      array $tags Tags currently viewing
	 * @return     void
	 */
	protected function _buildPathway($tags=null)
	{
		$pathway = JFactory::getApplication()->getPathway();

		if (count($pathway->getPathWay()) <= 0) 
		{
			$pathway->addItem(
				JText::_(strtoupper($this->_option)),
				'index.php?option=' . $this->_option
			);
		}
		if ($this->_task && $this->_task != 'display') 
		{
			$pathway->addItem(
				JText::_(strtoupper($this->_option) . '_' . strtoupper($this->_task)),
				'index.php?option=' . $this->_option . '&task=' . $this->_task
			);
		}
	}

	/**
	 * Method to build and set the document title
	 * 
	 * @param      array $tags Tags currently viewing
	 * @return     void
	 */
	protected function _buildTitle($tags=null)
	{
		$this->view->title = JText::_(strtoupper($this->_option));
		if ($this->_task && $this->_task != 'display') 
		{
			$this->view->title .= ': ' . JText::_(strtoupper($this->_option) . '_' . strtoupper($this->_task));
		}

		JFactory::getDocument()->setTitle($this->view->title);
	}
}
